@@ -13,7 +13,7 @@ from .items import bw_items
 from .lock import bw_lock_add, bw_lock_remove, bw_lock_show
 from .metadata import bw_metadata
 from .nodes import bw_nodes
-from .plot import bw_plot_group, bw_plot_node, bw_plot_node_groups
+from .plot import bw_plot_group, bw_plot_node, bw_plot_node_groups, bw_plot_reactors
 from .repo import bw_repo_bundle_create, bw_repo_create
 from .run import bw_run
 from .stats import bw_stats
@@ -532,6 +532,23 @@ bundle:my_bundle  # items in this bundle
         type=str,
         help=HELP_get_target_nodes,
     )
+    parser_lock_show.add_argument(
+        "-i",
+        "--items",
+        default=None,
+        dest='items',
+        help=_("""check locks against items matching any SELECTOR:
+
+file:/my_path     # this specific item
+tag:my_tag        # items with this tag
+bundle:my_bundle  # items in this bundle
+
+will exit with code 47 if any matching items are locked
+        """),
+        metavar=_("SELECTOR"),
+        nargs='+',
+        type=str,
+    )
     bw_lock_show_p_default = int(environ.get("BW_NODE_WORKERS", "4"))
     parser_lock_show.add_argument(
         "-p",
@@ -735,6 +752,47 @@ bundle:my_bundle  # items in this bundle
         help=_("node to plot"),
     )
 
+    # bw plot reactors
+    help_plot_node_reactors = _(
+        "Show metadata reactor information flow for a node. "
+        "Boxes are reactors, ovals are metadata paths provided or needed by reactors. "
+        "Accesses to other nodes' metadata are truncated by default and shown in red. "
+        "Numbers behind reactor names indicate how often the reactor result "
+        "changed vs. how often the reactor was run (0/1 is perfect efficiency)."
+    )
+    parser_plot_subparsers_node_reactors = parser_plot_subparsers.add_parser(
+        "reactors",
+        description=help_plot_node_reactors,
+        help=help_plot_node_reactors,
+    )
+    parser_plot_subparsers_node_reactors.set_defaults(func=bw_plot_reactors)
+    parser_plot_subparsers_node_reactors.add_argument(
+        'node',
+        metavar=_("NODE"),
+        type=str,
+        help=_("node to plot"),
+    )
+    parser_plot_subparsers_node_reactors.add_argument(
+        "-k", "--keys",
+        default=[],
+        dest='keys',
+        metavar=_("KEY"),
+        nargs='*',
+        type=str,
+        help=_(
+            "request only partial metadata from the given key paths "
+            "(e.g. `bw plot reactors mynode -k users/jdoe` "
+            "to show `mynode.metadata['users']['jdoe']`)"
+        ),
+    )
+    parser_plot_subparsers_node_reactors.add_argument(
+        "-r"
+        "--recursive",
+        action='store_true',
+        dest='recursive',
+        help=_("do not truncate plot when crossing to other nodes (result might be huge)"),
+    )
+
     # bw repo
     help_repo = _("Various subcommands to manipulate your repository")
     parser_repo = subparsers.add_parser("repo", description=help_repo, help=help_repo)
