@@ -122,7 +122,7 @@ def check_for_metadata_conflicts_between_defaults_and_reactors(node):
 
     for prefix in ("metadata_defaults:", "metadata_reactor:"):
         paths = {}
-        node.metadata.get(tuple())  # ensure full metadata is present
+        node.metadata.get(())  # ensure full metadata is present
         for partition in node.metadata.stack._partitions:
             for identifier, layer in partition.items():
                 if identifier.startswith(prefix):
@@ -242,8 +242,7 @@ def check_for_metadata_conflicts_between_groups(node):
                 else:
                     if keypath in keymap2:
                         if (
-                            type(value_at_key_path(chain_metadata[index1], keypath)) ==
-                            type(value_at_key_path(chain_metadata[index2], keypath)) and
+                            type(value_at_key_path(chain_metadata[index1], keypath)) is type(value_at_key_path(chain_metadata[index2], keypath)) and
                             type(value_at_key_path(chain_metadata[index2], keypath)) in
                             (set, dict)
                         ):
